@@ -166,9 +166,9 @@ reader_class_init (YelpReaderClass *klass)
 			      G_STRUCT_OFFSET (YelpReaderClass,
 					       finished),
 			      NULL, NULL,
-			      yelp_marshal_VOID__VOID,
+			      yelp_marshal_VOID__POINTER,
 			      G_TYPE_NONE,
-			      0);
+			      1, G_TYPE_POINTER);
 	signals[CANCELLED] =
 		g_signal_new ("cancelled",
 			      G_TYPE_FROM_CLASS (klass),
@@ -239,25 +239,29 @@ reader_convert_start (ReaderThreadData *th_data)
 
 	switch (yelp_uri_get_type (uri)) {
 	case YELP_URI_TYPE_MAN:
-		command_line = g_strdup_printf ("gnome2-man2html %s",
+		command_line = g_strdup_printf ("%s %s",
+						LIBGNOME_MAN2HTML,
 						yelp_uri_get_path (uri));
 		break;
 	case YELP_URI_TYPE_INFO:
 		if (yelp_uri_get_section (uri)) {
 			command_line = 
-				g_strdup_printf ("gnome2-info2html %s?%s",
-						 yelp_uri_get_path (uri),
-						 yelp_uri_get_section (uri));
+				g_strdup_printf ("%s %s?%s",
+						LIBGNOME_INFO2HTML,
+						yelp_uri_get_path (uri),
+						yelp_uri_get_section (uri));
 		} else { 
 			command_line = 
-				g_strdup_printf ("gnome2-info2html %s",
-						 yelp_uri_get_path (uri));
+				g_strdup_printf ("%s %s",
+						LIBGNOME_INFO2HTML,
+						yelp_uri_get_path (uri));
 		}
 		
 		break;
 	case YELP_URI_TYPE_DOCBOOK_XML:
 	case YELP_URI_TYPE_DOCBOOK_SGML:
-		command_line = g_strdup_printf ("yelp-db2html %s",
+		command_line = g_strdup_printf ("%s/yelp-db2html %s",
+						SERVERDIR,
 						yelp_uri_get_path (uri));
 		break;
 	default:
@@ -346,8 +350,7 @@ reader_file_start (ReaderThreadData *th_data)
 	gchar             buffer[BUFFER_SIZE];
 	GnomeVFSFileSize  n;
 	
-	g_return_if_fail (YELP_IS_READER (reader));
-	g_return_if_fail (uri != NULL);
+	g_return_if_fail (th_data != NULL);
 
 	reader = th_data->reader;
 	priv   = reader->priv;
@@ -403,7 +406,7 @@ reader_file_start (ReaderThreadData *th_data)
 	}
 	
 	q_data = reader_q_data_new (reader, stamp, READER_QUEUE_TYPE_FINISHED);
-	
+
 	g_async_queue_push (priv->thread_queue, q_data);
 }
 
@@ -441,6 +444,10 @@ reader_start (ReaderThreadData *th_data)
 	
 	d(g_print ("reader_start\n"));
 
+	if (!yelp_uri_exists (uri)) {
+		return NULL;
+	}
+
 	STAMP_MUTEX_LOCK;
 	
 	if (reader_check_cancelled (reader, th_data->stamp)) {
@@ -473,9 +480,6 @@ reader_start (ReaderThreadData *th_data)
 	case YELP_URI_TYPE_TOC:
 		/* Should this be handled here?? */
 		break;
-	case YELP_URI_TYPE_NON_EXISTENT:
-		/* Set GError and signal error */
-		break;
 	case YELP_URI_TYPE_INDEX:
 	case YELP_URI_TYPE_PATH:
 		/* Hmm .. is this wrong or what?? */
@@ -582,7 +586,8 @@ reader_idle_check_queue (ReaderThreadData *th_data)
 				priv->stamp = 1;
 			}
 
-			g_signal_emit (reader, signals[FINISHED], 0);
+			g_signal_emit (reader, signals[FINISHED], 0,
+				       th_data->uri);
 
 			ret_val = FALSE;
 			break;
@@ -654,8 +659,8 @@ reader_get_chunk (const gchar *document, const gchar *section)
 	end = strstr (document, "<!-- End of header -->");
 	
 	if (!end) {
-		g_warning ("Wrong type of document\n");
-		return NULL;
+/* 		g_warning ("Wrong type of document\n"); */
+		return g_strdup (document);
 	}
 	
 	header = g_strndup (document, end - document);
@@ -665,20 +670,20 @@ reader_get_chunk (const gchar *document, const gchar *section)
 	g_free (tag);
 	
 	if (!start) {
-		g_warning ("Document doesn't include section: '%s'", section);
+/* 		g_warning ("Document doesn't include section: '%s'", section); */
 		g_free (header);
-		
-		return NULL;
+
+		return g_strdup (document);
 	}
 
 	end = strstr (start, "<!-- End of chunk -->");
 
 	if (!end) {
-		g_warning ("Document is doesn't contain end tag for section: %s",
-			   section);
+/* 		g_warning ("Document is doesn't contain end tag for section: %s", */
+/* 			   section); */
 		g_free (header);
-		
-		return NULL;
+
+		return g_strdup (document);
 	}
 	
 	chunk = g_strndup (start, end - start);
@@ -686,11 +691,11 @@ reader_get_chunk (const gchar *document, const gchar *section)
 	footer = strstr (document, "<!-- Start of footer -->");
 	
 	if (!footer) {
-		g_warning ("Couldn't find footer in document");
+/* 		g_warning ("Couldn't find footer in document"); */
 		g_free (header);
 		g_free (chunk);
-		
-		return NULL;
+
+		return g_strdup (document);
 	}
 	 
 	ret_val = g_strconcat (header, chunk, footer, NULL);
@@ -791,9 +796,11 @@ yelp_reader_start (YelpReader *reader, YelpURI *uri)
 	
 	g_timeout_add (100, (GSourceFunc) reader_idle_check_queue, th_data);
 
-	g_thread_create ((GThreadFunc) reader_start, th_data,
-			 TRUE, 
-			 NULL /* FIXME: check for errors */);
+	g_thread_create_full ((GThreadFunc) reader_start, th_data,
+			      2 * BUFFER_SIZE,
+			      TRUE,
+			      FALSE, G_THREAD_PRIORITY_NORMAL,
+			      NULL /* FIXME: check for errors */);
 	return FALSE;
 }
 
