@@ -335,7 +335,7 @@ toc_start (YelpViewTOC *view)
 	}
 
 	yelp_html_printf (priv->html_view,
-			  "</ul></td><td bgcolor=\"#3b3b4f\" width=\"10%\">&nbsp;</td></tr>");
+			  "</ul></td><td bgcolor=\"#3b3b4f\" width=\"10%%\">&nbsp;</td></tr>");
 	
 	toc_page_end (view);
 
@@ -418,7 +418,7 @@ toc_man_emit (YelpViewTOC *view, GNode *first)
 		yelp_html_printf (priv->html_view, "<h3>%s</h3>", str_docs);
 
 		yelp_html_write (priv->html_view,
-				 "<table cellpadding=\"2\" cellspacing=\"2\" border=\"0\" width=\"100%\">\n",
+				 "<table cellpadding=\"2\" cellspacing=\"2\" border=\"0\" width=\"100%%\">\n",
 				 -1);
 
 		i = 0;
@@ -494,7 +494,7 @@ toc_man_2 (YelpViewTOC *view,
 	toc_man_emit (view, first);
 
 	yelp_html_printf (priv->html_view,
-			  "</td><td bgcolor=\"#3b3b4f\" width=\"10%\">&nbsp;</td></tr>\n");
+			  "</td><td bgcolor=\"#3b3b4f\" width=\"10%%\">&nbsp;</td></tr>\n");
 		
 	toc_page_end (view);
 
@@ -551,7 +551,7 @@ toc_man_1 (YelpViewTOC *view)
 	} while ((node = g_node_next_sibling (node)));
 
 	yelp_html_printf (priv->html_view,
-			  "</ul></td><td bgcolor=\"#3b3b4f\" width=\"10%\">&nbsp;</td></tr>");
+			  "</ul></td><td bgcolor=\"#3b3b4f\" width=\"10%%\">&nbsp;</td></tr>");
 
 	toc_page_end (view);
 
@@ -605,7 +605,7 @@ toc_info (YelpViewTOC *view)
 	} while ((node = g_node_next_sibling (node)));
 	
 	yelp_html_printf (priv->html_view,
-			  "</ul></td><td bgcolor=\"#3b3b4f\" width=\"10%\">&nbsp;</td></tr>");
+			  "</ul></td><td bgcolor=\"#3b3b4f\" width=\"10%%\">&nbsp;</td></tr>");
 
 	toc_page_end (view);
 
@@ -708,13 +708,13 @@ toc_page_start (YelpViewTOC *view, const gchar *title, const gchar *heading)
 			  "<body marginwidth=\"0\"\n"
 			  "background=\"file:" IMAGEDIR "/bcg.png\" marginheight=\"0\"\n"
 			  "border=\"10\" topmargin=\"0\" leftmargin=\"0\">\n"
-			  "<table width=\"100%\" border=\"0\" cellpadding=\"4\" cellspacing=\"0\">\n"
+			  "<table width=\"100%%\" border=\"0\" cellpadding=\"4\" cellspacing=\"0\">\n"
 			  "<tr valign=\"top\">\n"
 			  "<td width=\"75\">\n"
 			  "<img alt=\"\" src=\"file:" IMAGEDIR "/empty.png\" width=\"75\" height=\"1\">\n"
 			  "</td>\n"
 			  "<td colspan=\"2\"><h1>%s</h1></td>\n"
-			  "<td bgcolor=\"#3b3b4f\" width=\"10%\">&nbsp;</td>\n"
+			  "<td bgcolor=\"#3b3b4f\" width=\"10%%\">&nbsp;</td>\n"
 			  "</tr>\n"
 			  "<tr valign=\"top\">\n"
 			  "<td width=\"75\">\n"
@@ -728,6 +728,9 @@ static void
 toc_page_end (YelpViewTOC *view)
 {
 	YelpViewTOCPriv *priv;
+	gchar           *str_gnome_is  = _("GNOME is");
+	gchar           *str_fs        = _("Free Software");
+	gchar           *str_copyright = _("(C)");
 	
 	g_return_if_fail (YELP_IS_VIEW_TOC (view));
 	
@@ -741,21 +744,24 @@ toc_page_end (YelpViewTOC *view)
 			  "<td colspan=\"2\">\n"
 			  "<img src=\"file:" IMAGEDIR "/empty.png\" height=\"200\">\n"
 			  "</td>\n"
-			  "<td bgcolor=\"#3b3b4f\" width=\"10%\">&nbsp;</td></tr>\n"
+			  "<td bgcolor=\"#3b3b4f\" width=\"10%%\">&nbsp;</td></tr>\n"
 			  "<tr valign=\"top\">\n"
 			  "<td width=\"75\"><img alt=\"\" src=\"file:" IMAGEDIR "/empty.png\" width=\"75\" height=\"1\"></td>\n"
 			  "<td>\n"
 			  "<a href=\"http://www.gnome.org\" target=\"_blank\">\n"
-			  "<img src=\"file:" IMAGEDIR "/gnome2-button.png\" width=\"64\" height=\"64\" border=\"0\">\n"
+			  "<img src=\"file:" IMAGEDIR "/gnome2-button.png\" border=\"0\">\n"
 			  "</a>\n"
 			  "</td>\n"
 			  "<td>\n"
-			  "<font size=\"-1\">GNOME is <a href=\"http://www.gnu.org/philosophy/free-sw.html\"><font size=\"-1\">Free Software</font></a> | <a href=\"http://www.gnome.org\"><font size=\"-1\">http://www.gnome.org</font></a><br>\n"
-			  "(C) 2001-2002 Mikael Hallendal</font>\n"
+			  "<font size=\"-1\">%s <a href=\"http://www.gnu.org/philosophy/free-sw.html\">%s</a> | <a href=\"http://www.gnome.org\">http://www.gnome.org</a><br>\n"
+			  "%s 2001-2002 Mikael Hallendal</font>\n"
 			  "</td>\n"
-			  "<td bgcolor=\"#3b3b4f\" width=\"10%\">&nbsp;</td>\n"
+			  "<td bgcolor=\"#3b3b4f\" width=\"10%%\">&nbsp;</td>\n"
 			  "</tr>\n"
-			  "</table></body></html>\n");
+			  "</table></body></html>\n",
+			  str_gnome_is,
+			  str_fs,
+			  str_copyright);
 }
 
 YelpViewTOC *
@@ -859,7 +865,7 @@ toc_scrollkeeper (YelpViewTOC *view, GNode *root)
 	}
 
 	yelp_html_printf (priv->html_view,
-			  "</ul></td><td bgcolor=\"#3b3b4f\" width=\"10%\">&nbsp;</td></tr>");
+			  "</ul></td><td bgcolor=\"#3b3b4f\" width=\"10%%\">&nbsp;</td></tr>");
 	
 	toc_page_end (view);
 
